Iter tools from karld
========================




Documentation
===============================

Read the docs: http://iter_karld_tools.readthedocs.org/en/latest/


Contributing:
==================
Submit any issues or questions here: https://github.com/johnwlockwood/iter_karld_tools/issues.

Make pull requests to **development** branch of
 https://github.com/johnwlockwood/iter_karld_tools.

**Documentation** is written in reStructuredText and currently uses the
 Sphinx style for field
 lists http://sphinx-doc.org/domains.html#info-field-lists

Check out closed pull requests to see the flow of development, as almost
every change to master is done via a pull request on **GitHub**. Code Reviews
are welcome, even on merged Pull Requests. Feel free to ask questions about
the code.
